emacs-diffs
[Top][All Lists]
Advanced

[Date Prev][Date Next][Thread Prev][Thread Next][Date Index][Thread Index]

[Emacs-diffs] /srv/bzr/emacs/trunk r102334: Silence idlw*.el compilation


From: Glenn Morris
Subject: [Emacs-diffs] /srv/bzr/emacs/trunk r102334: Silence idlw*.el compilation.
Date: Wed, 10 Nov 2010 19:53:16 -0800
User-agent: Bazaar (2.0.3)

------------------------------------------------------------
revno: 102334
committer: Glenn Morris <address@hidden>
branch nick: trunk
timestamp: Wed 2010-11-10 19:53:16 -0800
message:
  Silence idlw*.el compilation.
  
  * lisp/progmodes/idlw-complete-structtag.el: Remove unused dec `name'.
  
  * lisp/progmodes/idlwave.el (idlwave-routine-entry-compare-twins)
  (idlwave-study-twins): Prefix dynamic local variable `name'.
  (idlwave-routine-twin-compare): Update for above change.
  
  * lisp/progmodes/idlw-help.el (idlwave-do-mouse-completion-help):
  Prefix dynamic local variables `name', `kwd', and `link'.
  * lisp/progmodes/idlw-shell.el (idlwave-shell-complete-execcomm-help):
  * lisp/progmodes/idlw-complete-structtag.el
  (idlwave-complete-structure-tag-help):
  * lisp/progmodes/idlwave.el (idlwave-complete-sysvar-help)
  (idlwave-complete-sysvar-tag-help)
  (idlwave-complete-class-structure-tag-help):
  Update for above name changes.
modified:
  lisp/ChangeLog
  lisp/progmodes/idlw-complete-structtag.el
  lisp/progmodes/idlw-help.el
  lisp/progmodes/idlw-shell.el
  lisp/progmodes/idlwave.el
=== modified file 'lisp/ChangeLog'
--- a/lisp/ChangeLog    2010-11-10 22:27:02 +0000
+++ b/lisp/ChangeLog    2010-11-11 03:53:16 +0000
@@ -1,3 +1,21 @@
+2010-11-11  Glenn Morris  <address@hidden>
+
+       * progmodes/idlw-complete-structtag.el: Remove unused dec `name'.
+
+       * progmodes/idlwave.el (idlwave-routine-entry-compare-twins)
+       (idlwave-study-twins): Prefix dynamic local variable `name'.
+       (idlwave-routine-twin-compare): Update for above change.
+
+       * progmodes/idlw-help.el (idlwave-do-mouse-completion-help):
+       Prefix dynamic local variables `name', `kwd', and `link'.
+       * progmodes/idlw-shell.el (idlwave-shell-complete-execcomm-help):
+       * progmodes/idlw-complete-structtag.el
+       (idlwave-complete-structure-tag-help):
+       * progmodes/idlwave.el (idlwave-complete-sysvar-help)
+       (idlwave-complete-sysvar-tag-help)
+       (idlwave-complete-class-structure-tag-help):
+       Update for above name changes.
+
 2010-11-10  Lars Magne Ingebrigtsen  <address@hidden>
 
        * net/browse-url.el (browse-url-browser-function): Change the

=== modified file 'lisp/progmodes/idlw-complete-structtag.el'
--- a/lisp/progmodes/idlw-complete-structtag.el 2010-08-29 20:10:43 +0000
+++ b/lisp/progmodes/idlw-complete-structtag.el 2010-11-11 03:53:16 +0000
@@ -1,7 +1,7 @@
 ;;; idlw-complete-structtag.el --- Completion of structure tags.
 
-;; Copyright (C) 2001, 2002, 2003, 2004, 2005, 2006, 2007, 2008, 2009, 2010
-;;   Free Software Foundation, Inc.
+;; Copyright (C) 2001, 2002, 2003, 2004, 2005, 2006, 2007, 2008, 2009,
+;;   2010  Free Software Foundation, Inc.
 
 ;; Author: Carsten Dominik <address@hidden>
 ;; Maintainer: J.D. Smith <address@hidden>
@@ -225,9 +225,8 @@
 
 
 ;; Fake help in the source buffer for structure tags.
-;; kwd and name are global-variables here.
-(defvar name)
-(defvar kwd)
+;; idlw-help-kwd is a global-variable (from idlwave-do-mouse-completion-help).
+(defvar idlw-help-kwd)
 (defvar idlwave-help-do-struct-tag)
 (defun idlwave-complete-structure-tag-help (mode word)
   (cond
@@ -236,13 +235,10 @@
     (not (equal idlwave-current-tags-buffer
                 (get-buffer (idlwave-shell-buffer)))))
    ((eq mode 'set)
-    (setq kwd word
+    (setq idlw-help-kwd word
          idlwave-help-do-struct-tag idlwave-structtag-struct-location))
    (t (error "This should not happen"))))
 
 (provide 'idlw-complete-structtag)
 
 ;;; idlw-complete-structtag.el ends here
-
-
-;; arch-tag: d1f9e55c-e504-4187-9c31-3c3651fa4bfa

=== modified file 'lisp/progmodes/idlw-help.el'
--- a/lisp/progmodes/idlw-help.el       2010-08-29 20:10:43 +0000
+++ b/lisp/progmodes/idlw-help.el       2010-11-11 03:53:16 +0000
@@ -1,7 +1,7 @@
 ;;; idlw-help.el --- HTML Help code for IDLWAVE
 
-;; Copyright (C) 2000, 2001, 2002, 2003, 2004, 2005, 2006, 2007, 2008, 2009, 
2010
-;;   Free Software Foundation, Inc.
+;; Copyright (C) 2000, 2001, 2002, 2003, 2004, 2005, 2006, 2007, 2008,
+;;   2009, 2010  Free Software Foundation, Inc.
 ;;
 ;; Authors: J.D. Smith <address@hidden>
 ;;          Carsten Dominik <address@hidden>
@@ -576,13 +576,13 @@
   (let* ((cw (selected-window))
         (info idlwave-completion-help-info) ; global passed in
         (what (nth 0 info))
-        (name (nth 1 info))
+        (idlw-help-name (nth 1 info))
         (type (nth 2 info))
         (class (nth 3 info))
         (need-class class)
-        (kwd (nth 4 info))
+        (idlw-help-kwd (nth 4 info))
         (sclasses (nth 5 info))
-        word link)
+        word idlw-help-link)
     (mouse-set-point ev)
 
 
@@ -590,18 +590,18 @@
     (setq word (idlwave-this-word))
     (if (string= word "")
        (error "No help item selected"))
-    (setq link (get-text-property 0 'link word))
+    (setq idlw-help-link (get-text-property 0 'link word))
     (select-window cw)
     (cond
      ;; Routine name
      ((memq what '(procedure function routine))
-      (setq name word)
+      (setq idlw-help-name word)
       (if (or (eq class t)
              (and (stringp class) sclasses))
          (let* ((classes (idlwave-all-method-classes
-                          (idlwave-sintern-method name)
+                          (idlwave-sintern-method idlw-help-name)
                           type)))
-           (setq link t)               ; No specific link valid yet
+           (setq idlw-help-link t)             ; No specific link valid yet
            (if sclasses
                (setq classes (idlwave-members-only
                               classes (cons class sclasses))))
@@ -611,19 +611,19 @@
       ;; XXX is this necessary, given all-method-classes?
       (if (stringp class)
          (setq class (idlwave-find-inherited-class
-                      (idlwave-sintern-routine-or-method name class)
+                      (idlwave-sintern-routine-or-method idlw-help-name class)
                       type (idlwave-sintern-class class)))))
 
      ;; Keyword
      ((eq what 'keyword)
-      (setq kwd word)
+      (setq idlw-help-kwd word)
       (if (or (eq class t)
              (and (stringp class) sclasses))
          (let ((classes  (idlwave-all-method-keyword-classes
-                          (idlwave-sintern-method name)
-                          (idlwave-sintern-keyword kwd)
+                          (idlwave-sintern-method idlw-help-name)
+                          (idlwave-sintern-keyword idlw-help-kwd)
                           type)))
-           (setq link t) ; Link can't be correct yet
+           (setq idlw-help-link t) ; Link can't be correct yet
            (if sclasses
                (setq classes (idlwave-members-only
                               classes (cons class sclasses))))
@@ -632,11 +632,12 @@
            ;; XXX is this necessary, given all-method-keyword-classes?
            (if (stringp class)
                (setq class (idlwave-find-inherited-class
-                            (idlwave-sintern-routine-or-method name class)
+                            (idlwave-sintern-routine-or-method
+                             idlw-help-name class)
                             type (idlwave-sintern-class class)))))
-       (if (string= (downcase name) "obj_new")
+       (if (string= (downcase idlw-help-name) "obj_new")
            (setq class idlwave-current-obj_new-class
-                 name "Init"))))
+                 idlw-help-name "Init"))))
 
      ;; Class name
      ((eq what 'class)
@@ -649,9 +650,11 @@
       (funcall what 'set word))
 
      (t (error "Cannot help with this item")))
-    (if (and need-class (not class) (not (and link (not (eq link t)))))
+    (if (and need-class (not class)
+            (not (and idlw-help-link (not (eq idlw-help-link t)))))
        (error "Cannot help with this item"))
-    (idlwave-online-help link (or name word) type class kwd)))
+    (idlwave-online-help idlw-help-link (or idlw-help-name word)
+                        type class idlw-help-kwd)))
 
 (defvar idlwave-highlight-help-links-in-completion)
 (defvar idlwave-completion-help-links)
@@ -1383,5 +1386,4 @@
 (provide 'idlw-help)
 (provide 'idlwave-help)
 
-;; arch-tag: d27b5505-59de-497f-ba3f-f199fd4fb911
 ;;; idlw-help.el ends here

=== modified file 'lisp/progmodes/idlw-shell.el'
--- a/lisp/progmodes/idlwave.el 2010-11-09 05:33:07 +0000
+++ b/lisp/progmodes/idlwave.el 2010-11-11 03:53:16 +0000
@@ -7659,7 +7659,7 @@
             t)) ; return t to skip other completions
          (t nil))))
 
-(defvar link) ;dynamic variables set by help callback
+(defvar idlw-help-link) ;dynamic variables set by help callback
 (defun idlwave-complete-sysvar-help (mode word)
   (let ((word (or (nth 1 idlwave-completion-help-info) word))
        (entry (assoc word idlwave-system-variables-alist)))
@@ -7667,7 +7667,8 @@
      ((eq mode 'test)
       (and (stringp word) entry (nth 1 (assq 'link entry))))
      ((eq mode 'set)
-      (if entry (setq link (nth 1 (assq 'link entry))))) ;; setting dynamic!!!
+      ;; Setting dynamic!!!
+      (if entry (setq idlw-help-link (nth 1 (assq 'link entry)))))
      (t (error "This should not happen")))))
 
 (defun idlwave-complete-sysvar-tag-help (mode word)
@@ -7681,10 +7682,10 @@
       (and (stringp word) entry main))
      ((eq mode 'set)
       (if entry
-         (setq link
+         (setq idlw-help-link
                (if (setq target (cdr (assoc-string word tags t)))
-                 (idlwave-substitute-link-target main target)
-               main)))) ;; setting dynamic!!!
+                   (idlwave-substitute-link-target main target)
+                 main)))) ;; setting dynamic!!!
      (t (error "This should not happen")))))
 
 (defun idlwave-split-link-target (link)
@@ -7704,9 +7705,10 @@
       link)))
 
 ;; Fake help in the source buffer for class structure tags.
-;; KWD AND NAME ARE GLOBAL-VARIABLES HERE.
-(defvar name)
-(defvar kwd)
+;; IDLW-HELP-LINK AND IDLW-HELP-NAME ARE GLOBAL-VARIABLES HERE.
+;; (from idlwave-do-mouse-completion-help)
+(defvar idlw-help-name)
+(defvar idlw-help-link)
 (defvar idlwave-help-do-class-struct-tag nil)
 (defun idlwave-complete-class-structure-tag-help (mode word)
   (cond
@@ -7722,9 +7724,9 @@
                  idlwave-system-class-info)
            (error "No help available for system class tags"))
        (if (setq found-in (idlwave-class-found-in class-with))
-           (setq name (cons (concat found-in "__define") class-with))
-         (setq name (concat class-with "__define")))))
-    (setq kwd word
+           (setq idlw-help-name (cons (concat found-in "__define") class-with))
+         (setq idlw-help-name (concat class-with "__define")))))
+    (setq idlw-help-link word
          idlwave-help-do-class-struct-tag t))
    (t (error "This should not happen"))))
 
@@ -8802,7 +8804,7 @@
 non-dangerous because many IDL routines are implemented as library
 routines, and may have been scanned."
   (let* ((entry (car entries))
-        (name (car entry))      ;
+        (idlwave-twin-name (car entry))      ;
         (type (nth 1 entry))    ; Must be bound for
         (idlwave-twin-class (nth 2 entry)) ;  idlwave-routine-twin-compare
         (cnt 0)
@@ -8878,7 +8880,7 @@
 (defun idlwave-routine-entry-compare-twins (a b)
   "Compare two routine entries, under the assumption that they are twins.
 This basically calls `idlwave-routine-twin-compare' with the correct args."
-  (let* ((name (car a))
+  (let* ((idlwave-twin-name (car a))
         (type (nth 1 a))
         (idlwave-twin-class (nth 2 a)) ; used in idlwave-routine-twin-compare
         (asrc (nth 3 a))
@@ -8897,6 +8899,7 @@
 
 ;; Bound in idlwave-study-twins,idlwave-routine-entry-compare-twins.
 (defvar idlwave-twin-class)
+(defvar idlwave-twin-name)
 
 (defun idlwave-routine-twin-compare (a b)
   "Compare two routine twin entries for sorting.
@@ -8937,8 +8940,8 @@
         (fname-re (if idlwave-twin-class
                       (format "\\`%s__\\(%s\\|define\\)\\.pro\\'"
                               (regexp-quote (downcase idlwave-twin-class))
-                              (regexp-quote (downcase name)))
-                    (format "\\`%s\\.pro" (regexp-quote (downcase name)))))
+                              (regexp-quote (downcase idlwave-twin-name)))
+                    (format "\\`%s\\.pro" (regexp-quote (downcase 
idlwave-twin-name)))))
         ;; Is file name derived from the routine name?
         ;; Method file or class definition file?
         (anamep (string-match fname-re aname))


reply via email to

[Prev in Thread] Current Thread [Next in Thread]
--- a/lisp/progmodes/idlw-shell.el      2010-11-09 05:33:07 +0000
+++ b/lisp/progmodes/idlw-shell.el      2010-11-11 03:53:16 +0000
@@ -2180,8 +2180,8 @@
       ;; Default completion of modules and keywords
       (idlwave-complete arg)))))
 
-;; Get rid of opaque dynamic variable passing of link?
-(defvar link) ;dynamic variable
+;; Get rid of opaque dynamic variable passing of idlw-help-link?
+(defvar idlw-help-link) ; dynamic variable from 
idlwave-do-mouse-completion-help
 (defun idlwave-shell-complete-execcomm-help (mode word)
   (let ((word (or (nth 1 idlwave-completion-help-info) word))
        (entry (assoc-string word idlwave-executive-commands-alist t)))
@@ -2189,7 +2189,7 @@
      ((eq mode 'test)
       (and (stringp word) entry (cdr entry)))
      ((eq mode 'set)
-      (if entry (setq link (cdr entry)))) ;; setting dynamic variable!!!
+      (if entry (setq idlw-help-link (cdr entry)))) ; setting dynamic variable!
      (t (error "This should not happen")))))
 
 (defun idlwave-shell-complete-filename (&optional arg)

=== modified file 'lisp/progmodes/idlwave.el'